/*
 * Copyright (C) 1999 Arthur Jerijian
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files
 * (the "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to permit
 * persons to whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * In addition, permission is hereby granted, free of charge, to any person
 * obtaining a copy of the software, to deal in the Software according to the
 * terms outlined in the GNU General Public License (the "GPL") in lieu of the
 * licensing terms stated in the above permission notice.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER(S) OF THE SOFTWARE BE LIABLE FOR
 * ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
 * OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

/*
 * main.c: Main program entry point
 */

#include "common.h"
#include "panel.h"
#include "capture.h"
#include "stringtable.h"
#include "main.h"

gint delete_event (GtkWidget *widget, GdkEvent *event, gpointer data)
{
    return (FALSE);
}

void destroy (GtkWidget *widget, gpointer data)
{
    gtk_main_quit ();
}

/*********************************************************************
 *
 * MAIN FUNCTION
 */

int main (int argc, char *argv[])
{
    GtkWidget *window;
    GtkWidget *box;

    /* Call all toolkit initialization routines. */

    gdk_init (&argc, &argv);
    gdk_imlib_init ();
    gtk_init (&argc, &argv);

    /* Initialize capture functionality. */
    
    capture_init ();

    /* Create and initialize the main panel window. */
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);

    gtk_signal_connect
    (
        GTK_OBJECT (window),
        "delete_event",
        GTK_SIGNAL_FUNC (delete_event),
        NULL
    );
    gtk_signal_connect
    (
        GTK_OBJECT (window),
        "destroy",
        GTK_SIGNAL_FUNC (destroy),
        NULL
    );

    gtk_window_set_title (GTK_WINDOW (window), TITLE_PANEL);
    gtk_container_set_border_width (GTK_CONTAINER (window), 10);

    box = create_main_panel ();
    gtk_container_add (GTK_CONTAINER (window), box);

    gtk_widget_show (box);
    gtk_widget_show (window);

    /* Main GTK event loop */
    
    gtk_main ();

    /* Clean up capture functionality and free all data structures. */
    
    capture_cleanup ();

    return (0);
}
