/*
 * Copyright (C) 1999 Arthur Jerijian
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files
 * (the "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to permit
 * persons to whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * In addition, permission is hereby granted, free of charge, to any person
 * obtaining a copy of the software, to deal in the Software according to the
 * terms outlined in the GNU General Public License (the "GPL") in lieu of the
 * licensing terms stated in the above permission notice.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER(S) OF THE SOFTWARE BE LIABLE FOR
 * ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
 * OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

/*
 * util.c: Miscellaneous utility functions
 */

#include "common.h"
#include "stringtable.h"
#include "util.h"

/*********************************************************************
 *
 * error_dialog: Display a GTK dialog box with an error message.
 *
 * Parameters:
 *   error_msg - text to display within the error dialog box
 *
 * Return value:
 *   None.
 */

void error_dialog (gchar *error_msg)
{
    GtkWidget *error_dialog;
    GtkWidget *label;
    GtkWidget *OK_button;

    error_dialog = gtk_dialog_new ();
    gtk_window_set_title (GTK_WINDOW (error_dialog), TITLE_ERROR);

    OK_button = gtk_button_new_with_label ("OK");
    gtk_signal_connect_object
    (
        GTK_OBJECT (OK_button),
        "clicked",
        GTK_SIGNAL_FUNC (gtk_widget_destroy),
        GTK_OBJECT (error_dialog)
    );
    gtk_box_pack_start
    (
        GTK_BOX (GTK_DIALOG (error_dialog) -> action_area),
        OK_button,
        TRUE,
        TRUE,
        0
    );
    gtk_widget_show (OK_button);

    label = gtk_label_new (error_msg);
    gtk_box_pack_start
    (
        GTK_BOX (GTK_DIALOG (error_dialog) -> vbox),
        label,
        TRUE,
        TRUE,
        0
    );
    gtk_widget_show (label);

    gtk_widget_show (error_dialog);
}

/*********************************************************************
 *
 * debug_print: Print a debug message to the console if debugging
 * is enabled during compile time.
 *
 * Parameters:
 *   debug_msg - debug message text without a trailing newline
 *
 * Return value:
 *   None.
 */

void debug_print (gchar *debug_msg)
{
#ifdef MAGICAPTURE_DEBUG
    GString *debug_buffer;
    
    debug_buffer = g_string_new (NULL);
    g_string_sprintf (debug_buffer, "%s\n", debug_msg);
    g_print (debug_buffer -> str);
    g_string_free (debug_buffer, TRUE);
#endif /* MAGICAPTURE_DEBUG */
}
